// Written by Dr. YIP Chi Lap [Beta]
//   for Workshop on "Scene Analysis Using Webcam",
//   Sea Level Measurement Device Design Competition,
//   Faculty of Engineering, The University of Hong Kong, 2014.
//   http://www.cs.hku.hk/~sealevel/

// Specify that video processing library is to be used.
import processing.video.*;


// This is made globally accessible representing the camera.
Capture camera;
int nPixels;


// This function is called when the program starts to run.
void setup() {
  // Sets the size of the display window.
  size(640, 480, P2D);
  // Creates the camera object.
  camera = new Capture(this,width,height);
  // Starts the camera for capturing.
  camera.start();
  // Remember the total number of pixels for the camera.
  nPixels = camera.width * camera.height;
  // This make the screen pixels available
  //   for manipulation in the pixels[] array.
  loadPixels();
}

// This function is called automatically
//   whenever the screen needs to be refreshed.
void draw() {
  if (camera.available()) {
    // Read the captured frame from camera.
    camera.read();
    // Make the pixels of the captured frame available for manipulation.
    camera.loadPixels();
    // Horizontally flip evey line.
    for (int y=0; y<camera.height; ++y) { // for each line
      for (int x=0; x<camera.width; ++x) { // for each position
        // Flips the screen horizontally, without using set(.,.,.)
        //
        // After a loadPixels() call,
        //   the screen pixel at (x,y) is available at pixels[y*width+x] .
        //
        // This applies to both pixels[.] and camera.pixels[.] .
        //
        // Here we copy the camera pixel at (x,y) to
        //   the screen pixel at (width-1-x,y),
        //   effectively flipping the screen horizontally.
        // Note that for camera pixels,
        //   y*camera.width+(width-1-x) equals (y+1)*camera.width-1-x,
        //   so we use the latter which is more simple.
        //
        pixels[y*width+x] = camera.pixels[(y+1)*camera.width-1-x];
      }
    }
    // This is to tell the system that the screen pixels have been modified
    //   and a redraw is needed.
    updatePixels();
  }
}
